==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-shape-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
var IgcGeographicShapeSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicShapeSeriesComponent, _super);
    function IgcGeographicShapeSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._styleShape = null;
        _this._styleShape_wrapped = null;
        return _this;
    }
    IgcGeographicShapeSeriesComponent.prototype.createImplementation = function () {
        return new GeographicShapeSeries();
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicShapeSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicShapeSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = names;
            }
            return IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent.register = function () {
        if (!IgcGeographicShapeSeriesComponent._isElementRegistered) {
            IgcGeographicShapeSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicShapeSeriesComponent.htmlTagName, IgcGeographicShapeSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "isPolygon", {
        /**
         * Gets whether the current series shows a polygon shape.
        */
        get: function () {
            return this.i.e4;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeFill", {
        /**
         * Gets or sets the fill brush.
        */
        get: function () {
            return this.i.wk ? this.i.wk.fill : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.wk.fill = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeStroke", {
        /**
         * Gets or sets the stroke brush.
        */
        get: function () {
            return this.i.wk ? this.i.wk.stroke : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.wk.stroke = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeStrokeThickness", {
        /**
         * Gets or sets the stroke thickness.
        */
        get: function () {
            return this.i.wk ? this.i.wk.strokeThickness : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.wk.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.wk.strokeThickness);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeOpacity", {
        /**
         * Gets or sets the opacity.
        */
        get: function () {
            return this.i.wk ? this.i.wk.opacity : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.wk.opacity = +v;
            this._a("shapeOpacity", this.i.wk.opacity);
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent.prototype.ensureShapeStyle = function () {
        if (this.i.wk) {
            return;
        }
        this.i.wk = new Style();
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: function () {
            return this.i.ve;
        },
        set: function (v) {
            this.i.ve = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.ve));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerOutlineMode", {
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get: function () {
            return this.i.vd;
        },
        set: function (v) {
            this.i.vd = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.vd));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerFillMode", {
        /**
         * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
        */
        get: function () {
            return this.i.vc;
        },
        set: function (v) {
            this.i.vc = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.vc));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: function () {
            return this.i.v0;
        },
        set: function (v) {
            this.i.v0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: function () {
            return brushToString(this.i.wh);
        },
        set: function (v) {
            this.i.wh = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.wh));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: function () {
            return brushToString(this.i.wi);
        },
        set: function (v) {
            this.i.wi = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.wi));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerThickness", {
        /**
         * Gets or sets thickness of the marker outline
        */
        get: function () {
            return this.i.vh;
        },
        set: function (v) {
            this.i.vh = +v;
            this._a("markerThickness", this.i.vh);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: function () {
            return this.i.vb;
        },
        set: function (v) {
            this.i.vb = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.vb));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: function () {
            return this.i.vz;
        },
        set: function (v) {
            this.i.vz = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: function () {
            return brushToString(this.i.wf);
        },
        set: function (v) {
            this.i.wf = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.wf));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: function () {
            return brushToString(this.i.wg);
        },
        set: function (v) {
            this.i.wg = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.wg));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "styleShape", {
        get: function () {
            return this._styleShape;
        },
        set: function (ev) {
            var _this = this;
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = function (o, e) {
                var outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeStyleShape) {
                    _this.beforeStyleShape(_this, outerArgs);
                }
                if (_this._styleShape) {
                    _this._styleShape(_this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = null;
    IgcGeographicShapeSeriesComponent.htmlTagName = "igc-geographic-shape-series";
    IgcGeographicShapeSeriesComponent._isElementRegistered = false;
    return IgcGeographicShapeSeriesComponent;
}(IgcGeographicShapeSeriesBaseComponent));
export { IgcGeographicShapeSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-shape-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
var IgcGeographicShapeSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicShapeSeriesComponent, _super);
    function IgcGeographicShapeSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._styleShape = null;
        _this._styleShape_wrapped = null;
        return _this;
    }
    IgcGeographicShapeSeriesComponent.prototype.createImplementation = function () {
        return new GeographicShapeSeries();
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicShapeSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicShapeSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = names;
            }
            return IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent.register = function () {
        if (!IgcGeographicShapeSeriesComponent._isElementRegistered) {
            IgcGeographicShapeSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicShapeSeriesComponent.htmlTagName, IgcGeographicShapeSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "isPolygon", {
        /**
         * Gets whether the current series shows a polygon shape.
        */
        get: function () {
            return this.i.fq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeFill", {
        /**
         * Gets or sets the fill brush.
        */
        get: function () {
            return this.i.zq ? this.i.zq.fill : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zq.fill = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeStroke", {
        /**
         * Gets or sets the stroke brush.
        */
        get: function () {
            return this.i.zq ? this.i.zq.stroke : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zq.stroke = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeStrokeThickness", {
        /**
         * Gets or sets the stroke thickness.
        */
        get: function () {
            return this.i.zq ? this.i.zq.strokeThickness : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zq.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.zq.strokeThickness);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "shapeOpacity", {
        /**
         * Gets or sets the opacity.
        */
        get: function () {
            return this.i.zq ? this.i.zq.opacity : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zq.opacity = +v;
            this._a("shapeOpacity", this.i.zq.opacity);
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent.prototype.ensureShapeStyle = function () {
        if (this.i.zq) {
            return;
        }
        this.i.zq = new Style();
    };
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: function () {
            return this.i.yk;
        },
        set: function (v) {
            this.i.yk = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.yk));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerOutlineMode", {
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get: function () {
            return this.i.yj;
        },
        set: function (v) {
            this.i.yj = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.yj));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerFillMode", {
        /**
         * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
        */
        get: function () {
            return this.i.yi;
        },
        set: function (v) {
            this.i.yi = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.yi));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: function () {
            return this.i.y6;
        },
        set: function (v) {
            this.i.y6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: function () {
            return brushToString(this.i.zn);
        },
        set: function (v) {
            this.i.zn = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.zn));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: function () {
            return brushToString(this.i.zo);
        },
        set: function (v) {
            this.i.zo = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.zo));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerThickness", {
        /**
         * Gets or sets thickness of the marker outline
        */
        get: function () {
            return this.i.yn;
        },
        set: function (v) {
            this.i.yn = +v;
            this._a("markerThickness", this.i.yn);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: function () {
            return this.i.yh;
        },
        set: function (v) {
            this.i.yh = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.yh));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: function () {
            return this.i.y5;
        },
        set: function (v) {
            this.i.y5 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: function () {
            return brushToString(this.i.zl);
        },
        set: function (v) {
            this.i.zl = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.zl));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: function () {
            return brushToString(this.i.zm);
        },
        set: function (v) {
            this.i.zm = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.zm));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicShapeSeriesComponent.prototype, "styleShape", {
        get: function () {
            return this._styleShape;
        },
        set: function (ev) {
            var _this = this;
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = function (o, e) {
                var outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeStyleShape) {
                    _this.beforeStyleShape(_this, outerArgs);
                }
                if (_this._styleShape) {
                    _this._styleShape(_this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = null;
    IgcGeographicShapeSeriesComponent.htmlTagName = "igc-geographic-shape-series";
    IgcGeographicShapeSeriesComponent._isElementRegistered = false;
    return IgcGeographicShapeSeriesComponent;
}(IgcGeographicShapeSeriesBaseComponent));
export { IgcGeographicShapeSeriesComponent };
